==> hapi-1.3.0.tar.gz: hapi-1.3.0/src/HapticShapeConstraint.cpp <==
//////////////////////////////////////////////////////////////////////////////
//    Copyright 2004-2014, SenseGraphics AB
//
//    This file is part of HAPI.
//
//    HAPI is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    HAPI is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with HAPI; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//    A commercial license is also available. Please contact us at 
//    www.sensegraphics.com for more information.
//
//
/// \file HapticShapeConstraint.cpp
/// \brief cpp file for HapticShapeConstraint
///
//
//////////////////////////////////////////////////////////////////////////////

#include <HAPI/HapticShapeConstraint.h> 

using namespace HAPI;

HapticShapeConstraint::HapticShapeConstraint(
                          Collision::CollisionObject *_col_obj,
                          const HAPIFloat &_spring_constant ):
  col_obj( _col_obj ),
  spring_constant( _spring_constant ){
}

HAPIForceEffect::EffectOutput HapticShapeConstraint::calculateForces(
    const EffectInput &input ) {
  Vec3 closest_point = Vec3(), temp;
  Vec3 hd_pos = input.hd->getPosition();
  col_obj->closestPoint( hd_pos, closest_point, temp, temp );
  Vec3 the_force = spring_constant * (closest_point - hd_pos);
  return EffectOutput( the_force );
}

==> hapi-1.4.0.tar.gz: hapi-1.4.0/src/HapticShapeConstraint.cpp <==
//////////////////////////////////////////////////////////////////////////////
//    Copyright 2004-2019, SenseGraphics AB
//
//    This file is part of HAPI.
//
//    HAPI is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    HAPI is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with HAPI; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//    A commercial license is also available. Please contact us at 
//    www.sensegraphics.com for more information.
//
//
/// \file HapticShapeConstraint.cpp
/// \brief cpp file for HapticShapeConstraint
///
//
//////////////////////////////////////////////////////////////////////////////

#include <HAPI/HapticShapeConstraint.h> 

using namespace HAPI;

HapticShapeConstraint::HapticShapeConstraint(
                          Collision::CollisionObject *_col_obj,
                          const HAPIFloat &_spring_constant,
                          bool _use_ref_count_lock ):
  HAPIForceEffect( _use_ref_count_lock ),
  col_obj( _col_obj ),
  spring_constant( _spring_constant ){
}

HAPIForceEffect::EffectOutput HapticShapeConstraint::calculateForces(
    const EffectInput &input ) {
  Vec3 closest_point = Vec3(), temp;
  Vec3 hd_pos = input.hd->getPosition();
  col_obj->closestPoint( hd_pos, closest_point, temp, temp );
  Vec3 the_force = spring_constant * (closest_point - hd_pos);
  return EffectOutput( the_force );
}
